********************************************************************************
******************************* DATA SET SPAIN *********************************
********************************************************************************

* 0. Prepare data

local time 2019T1 2019T2 2019T3 2019T4 2020T1 2020T2 2020T3

* Generate dataset for each quarter separately
foreach timing of local time {
	
clear

* Import variables in numerical format
qui import delimited "${d_`timing'}/EPA_`timing'.csv", numericcols(_all) 
drop nforma
save "${data_created}/EPA_`timing'_indiv.dta", replace
clear all

* Import education information as string variable
qui import delimited "${d_`timing'}/EPA_`timing'.csv", colrange(:20) 
keep nvivi npers nforma
qui merge 1:1 nvivi npers using "${data_created}/EPA_`timing'_indiv.dta"
drop _merge
save "${data_created}/EPA_`timing'_indiv.dta", replace


* Add variable labels
qui do "${do}/1_labels.do"

* 1. Generate relevant variables

* 1.1 General variables 

rename nvivi hh_id 							// household ID
egen indiv_id=concat(hh_id npers), punct(_) // individual ID
rename relpp1 relation						// inter-household relationship
rename ciclo t 								// quarter-year specifier
egen hh_t_id=group(hh_id t)					// household time ID
rename factorel wtfinl 						// weights for analysis

* Year and quarter dummies
gen year=.
gen Qt=.

local x = 186
foreach y of numlist 2019/2020 {
	replace year=`y' if t==`x' | t==`x'+1 | t==`x'+2 | t==`x'+3 
	replace Qt=1 if t==`x' 
	replace Qt=2 if  t==`x'+1 
	replace Qt=3 if t==`x'+2 
	replace Qt=4 if t==`x'+3 
	local x = `x'+4
}

* 1.2 Individual level variables for analysis (covariates)

*** Age
rename edad5 age
	
* Age groups (relevant ages for analysis)
gen age_grp = .
replace age_grp = 0 if age>=25 & age<30
replace age_grp = 1 if age>=30 & age<35
replace age_grp = 2 if age>=35 & age<40
replace age_grp = 3 if age>=40 & age<45
replace age_grp = 4 if age>=45 & age<50
replace age_grp = 5 if age>=50 & age<55


*** Gender 
rename sexo1 sex
recode sex(6=2) 


*** Marital status 
* Married
gen married = .
replace married = 1 if eciv1==2
replace married = 0 if eciv1!=2 & eciv1!=.

* Cohabiting
gen cohab=(ncony!=0)

* Married or cohabiting
gen mar_cohab=0 if married!=. | cohab!=.
replace mar_cohab=1 if married==1 | cohab==1


*** Education
* Education groups
gen simp_educ = .
replace simp_educ = 0 if nforma=="AN" | nforma=="P1" | nforma=="P2" | nforma=="S1" // < less than hs diploma or equivalent
replace simp_educ = 1 if nforma=="SG" | nforma=="SP" //  hs diploma or equivalent
replace simp_educ = 2 if nforma=="SU" // some college or associatess OR BA or more

* College dummy 
gen college=0 if nforma=="AN" | nforma=="P1" | nforma=="P2" | nforma=="S1" | nforma=="SG" | nforma=="SP"
replace college=1 if nforma=="SU" 


*** Migration variable 

* Born outside Spain
gen born_out=1 if regna1!=. & prona1==.
replace born_out=0 if prona1!=. & regna1==.

* Spanish nationality and born inside Spain vs. foreign nationality or Spanish 
* and born outside Spain
gen migrate=.
replace migrate=0 if nac1==1 | (nac1==2 & born_out==0)
replace migrate=1 if nac1==3 | (nac1==2 & born_out==1)


*** Occupation and industry
gen simp_occ=ocup1
replace simp_occ = 99 if simp_occ==. // necessary to avoid dropping in regressions

/* Occupation classifications
1 Directors and managers
2 Scientific and intellectual technicians and professionals
3 Support technicians and professionals
4 Administrative type employees
5 Workers in catering, personal, and protection services and trade salespersons
6 Workers skilles in agriculture and fishing
7 Craftspersons and workers qualifies for the manufacturing, construction, and mining industries, except installation and machinery operators
8 Installation and machinery operators and assemblers
9 Unskilled workers					  
*/					  
					  
gen simp_ind=act1
replace simp_ind=simp_ind+1
replace simp_ind = 99 if simp_ind==. // necessary to avoid dropping in regressions

/* Industry classifications
1 Agriculture, livestock farming, forestry and fisheries
2 Food, textile, leather, wood, and paper industries
3 Extractive industry, oil refining, chemical industry, pharmaceutical industry, rubber industry, plastic industry, energy supplies, gas, steam and air conditioning, water supplies, sourcing management, metallurgy
4 Machine builiding, electrical equipment and transportation material. Industrial installations and repair work
5 Construction
6 Wholesale and retail trade and related installations and repair work. Car repair, hospitality
7 Transportation and storage. Information and communication
8 Financial brokerage, insurance, property business, professional, scientific, administrative and other services
9 Public administration, education, and healthcare operations
10 Other services
*/

* Summer education sector indicator
gen sum_edu = 0
replace sum_edu = 1 if simp_ind==9 & Qt==3 // Public administration, education, and healthcare operations


*** Children and parenthood

* Reshape and add structure to identify parents of (young) children in hh
clonevar age_cat=age
label values age_cat age
label define age 0 "0_4" 5 "5_9" 10 "10_15" 16 "16_19" 20 "20_24" 25 "25_29" ///
	30 "30-34" 35 "35-39" 40 "40-44" 45 "45-49" 50 "50-54" 55 "55-59" 60 "60-64" ///
	65 "65+"

foreach x in 0 5 10 16 20 {
	preserve
		drop if age_cat!=`x'
		drop if npadre==0 & nmadre==0	// no parents in this hh
		drop if relation==1 | relation==2	// drop if individuals aren't "children" of some other hh member, but form own hh (relevant for middle aged children)
		bysort hh_id: gen child_n=_n
		egen child = concat(age_cat child_n), punct(_)	decode
		keep hh_id npadre nmadre child
		reshape wide npadre nmadre, i(hh_id) j(child) string
		save "${data_created}/child_`x'_`timing'.dta", replace
	restore
	merge m:1 hh_id using "${data_created}/child_`x'_`timing'.dta"
	cap drop _merge
	erase "${data_created}/child_`x'_`timing'.dta"
}

* Dummy for whether someone is parent of a specific child 
* (max. 10 in each age category should account for any household structure)
local x 0_4_1 0_4_2 0_4_3 0_4_4 0_4_5 0_4_6 0_4_7 0_4_8 0_4_9 0_4_10 ///
	5_9_1 5_9_2 5_9_3 5_9_4 5_9_5 5_9_6 5_9_7 5_9_8 5_9_9 5_9_10 ///
	10_15_1 10_15_2 10_15_3 10_15_4 10_15_5 10_15_6 10_15_7 10_15_8 10_15_9 10_15_10 ///
	16_19_1 16_19_2 16_19_3 16_19_4 16_19_5 16_19_6 16_19_7 16_19_8 16_19_9 16_19_10 ///
	20_24_1 20_24_2 20_24_3 20_24_4 20_24_5 20_24_6 20_24_7 20_24_8 20_24_9 20_24_10

foreach y of local x {
	cap gen mother_`y'=(npers==nmadre`y')
	cap gen father_`y'=(npers==npadre`y')
	local vars nmadre npadre
	foreach var of local vars {
		cap rename `var'`y' `var'_`y'
	}
}

* Number of own (bio or step) children (young, middle and old) in hh by age group
* Dummy for mother/father of children by age group
local vars mother_0_4 father_0_4 mother_5_9 father_5_9 mother_10_15 father_10_15 ///
	mother_16_19 father_16_19 mother_20_24 father_20_24
foreach x of local vars {
	local y `x'*
	cap egen `x'_n=rowtotal(`y'), missing
	cap gen `x'=(`x'_n>=1 & `x'_n!=.)
}

local age 0_4 5_9 10_15 16_19 20_24
foreach x of local age {
	gen parent_`x'=(mother_`x'==1 | father_`x'==1)
}

* Age of youngest own child
bysort hh_id: gen age_ychild_p=1 if parent_0_4==1
replace age_ychild_p=2 if parent_0_4==0 & parent_5_9==1
replace age_ychild_p=3 if parent_0_4==0 & parent_5_9==0 & parent_10_15==1
replace age_ychild_p=0 if parent_0_4==0 & parent_5_9==0 & parent_10_15==0

* Parent of child aged 0-15
gen parent=(parent_0_4==1 | parent_5_9==1 | parent_10_15==1)

*** Child groups (used for analysis)
gen child_grp = .
replace child_grp = 0 if parent==0 			// no children (=no or 20+)
replace child_grp = 1 if age_ychild_p==1 	// small kids (=0-4)
replace child_grp = 2 if age_ychild_p==2 | age_ychild_p==3	// middle kids (=5-15)
replace child_grp = 2 if parent_16_19==1 & parent==0 // not a parent of a child aged <=15, but parent of 16-19 year old


*** Pandemic Treatment and Control
gen Dt = . 
replace Dt = 0 if year<=2019 | year==2020 & Qt==1		// pre-pandemic = 0,  <= 2020Q1
replace Dt = 1 if year==2020 & (Qt==2 | Qt==3) 	// post-pandemic = 1, 2020Q2 + 2020Q3


* 1.3 Labor market outcomes 

*** Employment 

* INE definition employment rate = "This is the quotient between the total number of employed persons and the population aged 16 years and over."
* Source: https://ine.es/dynt3/metadatos/en/RespuestaPrint.html?oper=293

* Detailed definition of employment, see https://ine.es/en/inebaseDYN/epa30308/docs/resumetepa_en.pdf (p.13 ff)
* Broad employment
gen broad_emp=0 if nivel==1 // defined only for people of 16+ years
replace broad_emp=1 if trarem==1	// worked during last week
replace broad_emp=1 if ausent==1 & (rznotb==1 | rznotb==2 | rznotb==4) 
	// absent due to vacations, birth of child, or illness
replace broad_emp=1 if ausent==1 & (rznotb==3 | rznotb==5 | rznotb==6 | ///
	rznotb==9 | rznotb==10 | rznotb==11 | rznotb==12 | rznotb==13 | ///
	rznotb==14) & vincul==5 
	// absent for other reasons & back to work in <=3months or paid 50%+ 
replace broad_emp=1 if ayudfa==1
	// unpaid work in family business
replace broad_emp=1 if situ>=1 & situ<=3
	// absent from work & entrepreneur, independent worker of member of a cooperative 

	
*** Broad Hours Index

* Hours
// First 2 digits refer to hours, 2nd 2 digits to minutes
// Reshape into numeric hour variable
foreach x of varlist horase horplu {
	recode `x'(9999=.)
	gen str_`x' = string(`x', "%12.0f")
	gen length`x'=length(str_`x')
	gen zero`x'=0
	egen str_`x'2=concat(zero`x' str_`x') if length`x'==3, punct()
	replace str_`x'2=str_`x' if length`x'==4 // not defined for length`x'==1 & length`x'==2 since interpretation is unclear in this case
	gen h_`x' = real(substr(str_`x'2,1,2)) 
	gen min_`x' = real(substr(str_`x'2,3,4)) 
	gen hours_`x'=h_`x'+min_`x'/60
	replace hours_`x'=0 if `x'==0
	drop str_`x'* length`x' zero h_`x' min_`x' 
}

rename hours_horase hours_e1
rename hours_horplu hours_e2

egen hours_e_tot=rowtotal(hours_e1 hours_e2), missing
replace hours_e_tot=. if broad_emp==0

* Total hours worked last week (including unemployed)
gen raw_hours_lwk=hours_e_tot
replace raw_hours_lwk=0 if broad_emp==0 | (broad_emp==1 & ausent==1)
replace raw_hours_lwk=. if raw_hours_lwk>(24-8)*7 // drop those with impossibly high hours

* create hours index
// [See: MacCurdy and Pencavel JPE 1986]
gen hours_lwk   = ln(raw_hours_lwk + (1+raw_hours_lwk^2)^(1/2)) // hyperbolic sine transformation to approximate log funciton

save "${data_created}/EPA_`timing'_prelim.dta", replace

**********************
* Sample and Settings*
**********************

* Population Sample
keep if age>=25 & age<=50				// Keep age group of 25 to 54 years olds
drop if ocup1==0 | ocuplu==0	 		// Drop military
drop if relation==8						// Exclude domestic workers from family structure

* Reduce dataset to variables needed for analysis
keep broad_emp hours_lwk raw_hours_lwk Dt Qt year sex child_grp migrate sum_edu simp_educ college age_grp married mar_cohab simp_ind simp_occ wtfinl 

* Add variable labels for newly generated variables
qui do "${do}/1_labels.do"

save "${data_created}/EPA_`timing'_indiv.dta", replace

}

* Generate panel dataset
local time 2019T1 2019T2 2019T3 2019T4 2020T1 2020T2 
foreach timing of local time {
	qui append using "${data_created}/EPA_`timing'_indiv.dta"
}

* Time Index 
gen time_var = yq(year,Qt) 
gen sdate= string(time_var, "%tq") 
labmask time_var, val(sdate) // label time periods with quarter-year

* Compound work type groups for regressions, simple industry x simple occupation 
replace simp_ind = 99 if simp_occ==99 & simp_ind~=.
replace simp_occ = 99 if simp_ind==99 & simp_occ~=.
egen work_type = group(simp_occ simp_ind), label 

save "${data_created}/EPA_indiv_panel.dta", replace
