/* #############################################################################
Quarterly Labour Force Survey UK - Data preparation
############################################################################# */

* Preliminaries
clear


* Directories *
cd "${local_workdir}"


* Log File
log using "${out_dir}/UK_data_prep.log", replace

#delimit ;
local varlist 
SEX
AGE
HOHID 
MARSTA // marital status
ETHUKEUL // ethnicity (available from onwards 2012)

REFWKM REFWKY REFDTE // reference year, month, date

AYFL19 AYHL19 // age of youngest child in family OR household

MARDY6 // cohabiting with partner

WRKING JBAWAY // work variables
OWNBUS RELBUS // unpaid job in own / relatives' business
TYPSCH12 YTETJB // government scheme - TYPSCH12 available from 2012 onwards

SUMHRS TOTHRS // actual hours in all jobs / in ref week 
TTUSHR	// usual hours


SOC10M SC10LMN // occupations (available from 2011 onwards)

INDC07M INDS07M INDS07L // industry (available from 2009 onwards)

PWT18 // weights according to definition from 2018

HOME HOME2 // working from home

URESMC // region of usual residence
;


* LOADING QLFS data: 
// Q1/2020;
use `varlist' HIQUL15D using "${raw_data}/quarter/lfsp_jm20.dta";
// Q2/2020
append using "${raw_data}/quarter/lfsp_aj20.dta",
	keep(`varlist' TELEQA TELEQB HIQUL15D) nolabel;
// Q3/2020
append using "${raw_data}/quarter/lfsp_js20.dta",
	keep(`varlist' HIQUL15D) nolabel;

// Q1/2019;
append using "${raw_data}/quarter/lfsp_jm19.dta",
	keep(`varlist' HIQUL15D) nolabel;
// Q2/2019;
append using "${raw_data}/quarter/lfsp_aj19.dta",
	keep(`varlist' HIQUL15D) nolabel;
// Q3/2019;
append using "${raw_data}/quarter/lfsp_js19.dta",
	keep(`varlist' HIQUL15D) nolabel;
// Q4/2019;
append using "${raw_data}/quarter/lfsp_od19.dta",
	keep(`varlist' HIQUL15D) nolabel;

#delimit cr

******************************************************************************** 
* Renaming varibales*
*********************

* sex
rename SEX sex 

* Age of respondent
rename AGE age 



******************************************************************************** 
* Sample and Settings*
**********************

* Population Sample
keep if age>=25 & age<55
drop if SOC10M == 1171 | SOC10M == 3311 //drop military: officers in armed forces (1171) & full-time members of armed forces (3311)
drop if INDC07M == 8422 // drop defense activities (military) (see p. 219 of SIC2007-industry.pdf) INDC07M: industry class in main job, 4 digits
drop if HOHID == -9 // "does not apply" for household ID (some artefact in Q3/2019)
// Note that we cannot drop defense based on last job as well, as for last job we do have neither 4 digit SIC2007 nor 4 digit SOC2010 codes


* Time Index - month: (as in US)
gen month = REFWKM // define month
gen year = REFWKY // define year  
gen time_var = ym(year,month) 
gen sdate= string(time_var, "%tmmy") 
labmask time_var, val(sdate) // label time periods with month-year

* Time Index - Reference day:
gen refdate = date(REFDTE,"DMY")
format refdate %td

* Time Index - quarter:
gen dateq = qofd(refdate)
format dateq %tq

* create linear time variable:
egen min_dateq = min(dateq)
gen t = dateq - min_dateq + 1

* Labeling quarters:
gen dateq_label= string(dateq, "%tq") 
labmask dateq, val(dateq_label) // label time periods with quarter-year

* Define linear time variable:
gen time_var_reg = dateq // quarterly time variable


* Quarter dummies:
gen Qt = .
replace Qt = 1 if month >= 1 & month <= 3
replace Qt = 2 if month >= 4 & month <= 6
replace Qt = 3 if month >= 7 & month <= 9
replace Qt = 4 if month >= 10 & month <= 12

* Auxiliary Settings:

// Child age cutoffs:
local kid_cutoff = 5       // baseline: transition young to school age


******************************************************************************** 
* Create Variables *
********************

* Pandemic Treatment and Control
gen Dt = . 
replace Dt = 1 if year==2020 & month>=4 & month<=9   // post-pandemic = 1, 2020Q2 + 2020Q3
replace Dt = 0 if year==2020 & month>=1 & month<=3   // pre-pandemic = 0,  <= 2020Q1
replace Dt = 0 if year<=2019

* Child age group (2 groups)
// I use youngest child in the family. Should be most comparable to US definition: youngest own child in HH.
// all children in the family are also considered to be in the HH.
gen child_grp = .
replace child_grp = 0 if AYFL19== 19 // AYFL19: 19 - no dependent child aged under 19 
replace child_grp = 0 if AYFL19>= 18 & AYFL19<= 18 // AYFL19: 18 - youngest child is 18years old
replace child_grp = 1 if AYFL19>= 0 & AYFL19 < `kid_cutoff' // small kids <5
replace child_grp = 2 if AYFL19>=`kid_cutoff' & AYFL19<18  // big kids 5-17

* Broad Employment 
* (Employment-per-capita; For entire population combines unemployed and NILF, as in our model. Excludes armed services.)
* leave 279 missings aged 25-55 as they did not reply to the question if they worked last week.
gen broad_emp = .
replace broad_emp = 1 if WRKING == 1 | (WRKING == 2 & JBAWAY == 1) // working in ref week OR not working in ref week & away from job
replace broad_emp = 0 if JBAWAY == 2 | JBAWAY == 3 // not working in ref week & not away from job or waiting to start new job

** refinement of broad employment: 
// 1) if doing unpaid work in ones own business or in relative's business, then assigned as employed (previously assigned as non-employed):
replace broad_emp = 1 if OWNBUS == 1 | RELBUS == 1

// 2) if participation in government training scheme in ref week
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 1 	// working for an employer
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 2 	// temporarily away from an employer
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 3 	// working for a voluntary organsiation/charity
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 4 	// Other form of voluntary/community work
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 5 	// working for an environmental task force

replace broad_emp = 0 if broad_emp == . & TYPSCH12 == 6 	// In full-time or part-time study
replace broad_emp = 0 if broad_emp == . & TYPSCH12 == 7 	// temporarilty away from full-time or part-time study

replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 8 	// receiving help setting up as self-employed
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 9 	// providing work experience or practical training
replace broad_emp = 1 if broad_emp == . & TYPSCH12 == 10 // other form of employment training
														// other situation (11) and dont know (97) left as missings
replace broad_emp = 1 if TYPSCH12 > 0 & TYPSCH12 != . & YTETJB == 1 // on a government training scheme and doing a paid work in addition


* Broad hours measures (intensive and extensive margin):

* usual hours in the MAIN job
// can replace last week hours from below; challenge then is to deal with seasonality in last week hours
gen raw_hours_usual = .
replace raw_hours_usual = TTUSHR if TTUSHR >= 0 & TTUSHR != . & broad_emp != . // total usual hours (incl overtime) in MAIN job, careful with missing values coded as -8 and -9.
replace raw_hours_usual = 0 if broad_emp==0 // unemployed and NILF get zero hours, for extensive margin

* actual hours last week in all jobs
gen raw_hours_lwk = .
replace raw_hours_lwk = SUMHRS if SUMHRS >= 0 & SUMHRS != . & broad_emp != . // total actual hours worked in main and second job, careful with missing values coded as -8 and -9.
replace raw_hours_lwk = 0 if broad_emp==0 //unemployed and NILF get zero hours, for extensive margin
// use TOTHRS

* create hours indices - baseline: hyperbolic sine transformation
gen hours_usual = ln(raw_hours_usual + (1+raw_hours_usual^2)^(1/2)) // hyperbolic sine transformation to approximate log function
gen hours_lwk   = ln(raw_hours_lwk + (1+raw_hours_lwk^2)^(1/2)) // hyperbolic sine transformation to approximate log function

* Marital Status
gen married = .
replace married = 1 if MARSTA==2 | MARSTA==3 | MARSTA==6 // married, lving with partner | married separated from spouse | currently, or previously on civil partnershop 
replace married = 0 if MARSTA==1 | MARSTA==4 | MARSTA==5 // single, never married | divorced | widowed

* cohabitation with partner:
gen cohab = .
replace cohab = 1 if MARDY6 == 1 // cohabiting
replace cohab = 0 if MARDY6 == 2 // non-cohabiting


* Education
// details on groups - variable: HIQUAL15
gen simp_educ = .

// baseline: if education unknown to respondent, then assign missing
replace simp_educ = 0 if (HIQUL15D==4 | HIQUL15D==5 | HIQUL15D==6) 
	// less than GCE A-level equivalent = GCSE grade A*-C or equivalent | other lower qualification | no qualification

// remaining education levels:
replace simp_educ = 1 if HIQUL15D==3  // GCE A-level or equivalent: highest school diploma in UK 
replace simp_educ = 2 if HIQUL15D==2  // higher education: some college or vocational training, associates, etc
replace simp_educ = 3 if HIQUL15D==1  // university degree or equivalent: BA or more

* College education:
gen college = . 
replace college = 1 if simp_educ == 3
replace college = 0 if simp_educ == 0 | simp_educ == 1 | simp_educ == 2

* Simple race
gen simp_race = .
replace simp_race = 0 if ETHUKEUL == 1
replace simp_race = 1 if ETHUKEUL > 1 & ETHUKEUL != .

* Age groups
gen age_grp = .
replace age_grp = 0 if age>=25 & age<30
replace age_grp = 1 if age>=30 & age<35
replace age_grp = 2 if age>=35 & age<40
replace age_grp = 3 if age>=40 & age<45
replace age_grp = 4 if age>=45 & age<50
replace age_grp = 5 if age>=50 & age<55


* Region of usual residence:
rename URESMC region


* Occupations
* Note: UK LFS has a different occupational code as in US CPS. I used 25 sub-major groups which are defined in the following pdf. 
* sub-major groups = 2-digit occ codes.(for classification, see: soc2010-occupationalCodes.pdf)
gen simp_occ= .
replace simp_occ = int(SOC10M/100) if SOC10M > 1000 & SOC10M < 9300 // SOC10M: Occupation (main job) (4 digit SOC2010)

/* categories: SOC2010
11: Managers, Directors and Senior Officials 
12: Other Managers and Proprietors
21: Science, Research, Engeneering and Technology Professionals 
22: Health Professionals 
23: Teaching and Educational professionals 
24: Business, Media and Public Service Professionals 
31: Science, Engineering and Technology Associate Professionals
32: Health and social Care associate professionals 
33: Protective Service occuaptions 
34: Culture, media and sports occupations 
35: Businessand Public Service Associate Professionals 
41: Administrative Occupations 
42: Secreterial and related occupations 
51: Skilled Agricultural and related trades 
52: Skilled metal, electrical and electronic trades 
53: Skilled construction and building trades 
54: Textiles, printing and other skilled trades 
61: Caring personal service occupations 
62: Leisure, travel and relaed personal service occupations 
71: Sales occupations 
72: customer service occupations 
81: Process, plant and machine operatives 
82: Transport and mobile machine drivers and operatives 
91: Elementary trades and related occupations 
92: elementary adminstratiion and service occupaitons
*/

** Occupations of unemployed and NILF: 
// Use occupational info from last job if available. The rest are assigned into category 99. 
// Probably closest to US data, as unemployed in UK do not have an occupation, but do have one in the US CPS data.

** occupational info from last job (3 digit SOC2010)
replace simp_occ = int(SC10LMN/10) if simp_occ == . & SC10LMN > 100 & SC10LMN < 930 // SC10LMN: Occupation last job (3 digit SOC2010 - minor occupation group)

** rest assigned into category 99:
replace simp_occ = 99 if simp_occ == . & broad_emp == 0 // place holder for non-employed who do not have occupational info from previous job 
														// (most likely new workers and NILF)
														// (necessary to avoid dropping in regressions)



* Industry:
/* using SIC 2007 sections: 
1- A Agriculture, forestry and fishing
2- B Mining & quarrying
3- C Manufacturing
4- D Electricity, gas & air con supply
5- E Water supply, sewerage & waste
6- F Construction
7- G Distribution
8- H Transport & storage
9- I Accommodation & food services
10- J Information & communication
11- K Financial & insurance services
12- L Real estate services
13- M Professional, scientific & technical activities
14- N Admin & suppport services
15- O Public admin & defence (taken defense activities out in sample selection above - code: 8422)
16- P Education
17- Q Health & social work
18- R Arts, entertainment & recreation
BASELINE: pool cat 19- S Other service activities, 20- T Households as employers, and 21- U Extra territorial - only very few observations
*/
gen simp_ind = .
replace simp_ind = INDS07M if INDS07M > 0 & INDS07M != . // Industry section in main job (1 character)
replace simp_ind = 19 if simp_ind == 20 | simp_ind == 21

#delimit ;
label var simp_ind "1-digit Industry (SIC 2007)" ;
label define simp_ind_vals 
1 "Agriculture, forestry and fishing"
2 "Mining & quarrying"
3 "Manufacturing"
4 "Electricity, gas & air con supply"
5 "Water supply, sewerage & waste"
6 "Construction"
7 "Distribution"
8 "Transport & storage"
9 "Accommodation & food services"
10 "Information & communication"
11 "Financial & insurance services"
12 "Real estate services"
13 "Professional, scientific & technical activities"
14 "Admin & suppport services"
15 "Public admin & defence (w/o military)"
16 "Education"
17 "Health & social work"
18 "Arts, entertainment & recreation"
19 "Other activities"
99 "unknown industry of non-employed" ;
label values simp_ind simp_ind_vals ;
#delimit cr


** Industries of unemployed and NILF: 
// Use industry info from last job if available. The rest are assigned into category 99. 
// Probably closest to US data, as unemployed in UK partly do not have an industry from INDS07M, but unemployed do have one in the US CPS data.

** industry info from last job (1 character - same as above)
replace simp_ind = INDS07L if simp_ind == . & INDS07L > 0 & INDS07L != . // Industry section in main job (1 character)

** rest assigned into category 99:
replace simp_ind = 99 if simp_ind == . & broad_emp == 0 // place holder for non-employed who do not have industry info from previous job 
														// (most likely new workers and NILF)


** As we use a worktype, do not allow for interactions between 99 and non-99:
// of 513k observations, 34 have an industry but no occ and 750 have occ but no ind:
// not enough variation to have interactions also between ind=99 and occ as well as occ = 99 and ind. 
gen simp_ind_gr = simp_ind
replace simp_ind_gr = 99 if simp_occ == 99 & simp_ind != .
gen simp_occ_gr = simp_occ
replace simp_occ_gr = 99 if simp_ind == 99 & simp_occ != .

* Compound work type groups for regressions, simple industry x simple occupation 
egen work_type = group(simp_occ_gr simp_ind_gr), label 



* Telecommuting:

// baseline definition of telecommuting:
gen telecom = .
	// location of first job: (i) own home, (ii) same grounds or building, (iii) different places with home as a base 
replace telecom = 1 if HOME == 1 | HOME == 2 | HOME == 3 

	// location of first job: (iv) separate from home
replace telecom = 0 if HOME == 4


// Robustness definition of telecommuting:
gen telecom_rob = .
	// location of first job: (i) own home, (ii) same grounds or building
replace telecom_rob = 1 if HOME == 1 | HOME == 2 

	// location of first job: (iii) different places with home as a base  or (iv) separate from home
replace telecom_rob = 0 if HOME == 3 | HOME == 4 


* Summer Education Sector Indicator (Q3)
gen sum_edu = 0
replace sum_edu = 1 if simp_ind==16 & month>=7 & month<=9


********************************************************************************
* Save dataset *
*****************

// save data set for the event study plots and regression analyses:
save "${local_workdir}/UK_cleaned_data.dta", replace

log close
